<TeXmacs|1.0.7.3>

<style|generic>

<\body>
  <doc-data|<doc-title|Solving Linear Equations - Formulas>>

  <\with|font-base-size|12>
    <strong|Objective: Solve linear formulas for a given variable.>

    Solving formulas is much like solving general linear equations. The only
    difference is we will have several varaibles in the problem and we will
    be attempting to solve for one specific variable. For example, we may
    have a formula such as <math|A=\<pi\>r<rsup|2>+\<pi\>rs> (formula for
    surface area of a right circular cone) and we may be interested in
    solving for the varaible <math|s>. This means we want to isolate the
    <math|s> so the equation has <math|s> on one side, and everything else on
    the other. So a solution might look like
    <math|s=<frac|A-\<pi\>r<rsup|2>|\<pi\>s>>. This second equation gives the
    same information as the first, they are algebraically equivalent,
    however, one is solved for the area, while the other is solved for
    <math|s> (slant height of the cone). In this section we will discuss how
    we can move from the first equation to the second.

    When solving formulas for a variable we need to focus on the one varaible
    we are trying to solve for, all the others are treated just like numbers.
    This is shown in the following example. Two parallel problems are shown,
    the first is a normal one-step equation, the second is a formula that we
    are solving for x

    <\example>
      \;

      <\eqnarray*>
        <tformat|<table|<row|<cell|3x=12>|<cell|
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ w x=z>|<cell|In both problems,
        x is multiplied by something>>|<row|<cell|
        <with|math-font-series|bold|<wide| \ \ 3 \ \ |\<bar\>> \ \ \ \ <wide|
        \ \ 3 \ \ |\<bar\>>>>|<cell| \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ <with|math-font-series|bold|<wide|
        \ \ w \ \ |\<bar\>> \ \ \ \ <wide| \ \ w \ \ |\<bar\>>>>|<cell|To
        isolate the \ x we divide by 3 or w.>>|<row|<cell|x=4>|<cell|
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ x=<frac|z|w>>|<cell|Our
        Solution>>>>
      </eqnarray*>
    </example>

    We use the same process to solve <with|mode|math|3x=12> for
    <with|mode|math|x> as we use to solve <with|mode|math|w x=z> for
    <with|mode|math|x>. Because we are solving for <with|mode|math|x> we
    treat all the other variables the same way we would treat numbers. Thus,
    to get rid of the multiplication we divided by <with|mode|math|w>. This
    same idea is seen in the following example.

    <\example>
      \;

      <\eqnarray*>
        <tformat|<table|<row|<cell|m+n=p>|<cell|for n>|<cell|Solving for n,
        treat all other variables like numbers>>|<row|<cell|<wide*|<with|math-font-series|bold|-m
        \ \ \ \ \ \ \ \ \ -m>|\<bar\>>>|<cell|>|<cell|Subtract m from both
        sides>>|<row|<cell|n=p-m>|<cell|>|<cell|Our Solution>>>>
      </eqnarray*>
    </example>

    As <with|mode|math|p> and <with|mode|math|m> are not like terms, they
    cannot be combined. For this reason we leave the expression as
    <with|mode|math|p-m>. This same one-step process can be used with
    grouping symbols.

    <\example>
      \;

      <\eqnarray*>
        <tformat|<table|<row|<cell|a(x-y) \ \ \ \ = \ \ \ \ \ \ b
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ >|<cell|for a>|<cell|Solving for a, treat
        (x-y) like a number>>|<row|<cell|<with|math-font-series|bold|<wide|(x-y)|\<bar\>>
        \ \ <wide|(x-y)|\<bar\>>>>|<cell|>|<cell|Divide both sides by
        (x-y)>>|<row|<cell|>|<cell|>|<cell|>>|<row|<cell|a=<frac|b|x-y>>|<cell|>|<cell|Our
        Solution>>>>
      </eqnarray*>
    </example>

    Because <with|mode|math|(x-y)> is in parenthesis, if we are not searching
    for what is inside the parenthesis, we can keep them together as a group
    and divide by that group. However, if we are searching for what is inside
    the parenthesis, we will have to break up the parenthesis by
    distributing. The following example is the same formula, but this time we
    will solve for <with|mode|math|x>.

    <\example>
      \;

      <\eqnarray*>
        <tformat|<table|<row|<cell|a(x-y)=b>|<cell|for x>|<cell|Solving for
        x, we need to distribute to clear parenthesis>>|<row|<cell|a x-a
        y=b>|<cell|>|<cell|This is a two-step equation, a y is subtracted
        from our x term>>|<row|<cell|<with|math-font-series|bold|<wide*|+a y
        +a y|\<bar\>>>>|<cell|>|<cell|Add a y to both sides>>|<row|<cell|a
        x=b+a y>|<cell|>|<cell|The x is multipied by
        a>>|<row|<cell|<with|math-font-series|bold|<wide| \ \ a
        \ \ \ |\<bar\>> \ \ \ \ \ \ <wide| \ \ \ \ \ \ \ a
        \ \ \ \ \ \ \ |\<bar\>>> \ >|<cell|>|<cell|Divide both sides by
        a>>|<row|<cell|x=<frac|b+a y|a>>|<cell|>|<cell|Our Solution>>>>
      </eqnarray*>
    </example>

    Be very careful as we isolate <with|mode|math|x> that we do not try and
    cancel the <with|mode|math|a> on top and bottom of the fraction. This is
    not allowed if there is any adding or subtracting in the fraction. There
    is no reducing possible in this problem, so our final reduced answer
    remains <with|mode|math|x=<frac|b+a y|a>>. The next example is another
    two-step problem

    <\example>
      \;

      <\eqnarray*>
        <tformat|<table|<row|<cell|y=m x+b>|<cell|for m>|<cell|Solving for m,
        focus on addition first>>|<row|<cell|<with|math-font-series|bold|<wide*|-b
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ -b|\<bar\>>>>|<cell|>|<cell|Subtract
        b from both sides>>|<row|<cell|y-b=m x>|<cell|>|<cell|m is multipied
        by x. >>|<row|<cell| <with|math-font-series|bold|<wide|
        \ \ \ \ \ \ \ \ \ x \ \ \ \ \ \ \ \ \ |\<bar\>> \ \ \ \ \ <wide|
        \ \ x \ \ |\<bar\>>>>|<cell|>|<cell|Divide both sides by
        x>>|<row|<cell|<frac|y-b|x>=m>|<cell|>|<cell|Our Solution>>>>
      </eqnarray*>
    </example>

    It is important to note that we know we are done with the problem when
    the variable we are solving for is isolated or alone on one side of the
    equation and it does not appear anywhere on the other side of the
    equation.\ 

    The next example is also a two-step equation, it is the problem we
    started with at the beginning of the lesson.

    <\example>
      \;

      <\eqnarray*>
        <tformat|<table|<row|<cell|A=\<pi\>r<rsup|2>+\<pi\>r s>|<cell|for
        s>|<cell|Solving for s, focus on what is added to the term with
        s>>|<row|<cell|<with|math-font-series|bold|<wide*|-\<pi\>r<rsup|2>-\<pi\>r<rsup|2>|\<bar\>>
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ >>|<cell|>|<cell|Subtract
        \<pi\>r<rsup|2> from both sides>>|<row|<cell|A-\<pi\>r<rsup|2>=\<pi\>r
        s>|<cell|>|<cell|s is multipied by
        \<pi\>r>>|<row|<cell|<with|math-font-series|bold|<wide|
        \ \ \ \ \ \ \ \ \ \ \<pi\>r \ \ \ \ \ \ \ \ \ |\<bar\>>
        \ \ \ \ \ <wide| \ \ \<pi\>r \ \ |\<bar\>>>>|<cell|>|<cell|Divide
        both sides by \<pi\>r>>|<row|<cell|<frac|A-\<pi\>r<rsup|2>|\<pi\>r>=s>|<cell|>|<cell|Our
        Solution>>>>
      </eqnarray*>
    </example>

    Again, we cannot reduce the <with|mode|math|\<pi\>r> in the numerator and
    denominator because of the subtraction in the problem.\ 

    Formulas often have fractions in them and can be solved in much the same
    way we solved with fractions before. First identify the LCD and then
    multiply each term by the LCD. After we reduce there will be no more
    fractions in the problem so we can solve like any general equation from
    there.

    <\example>
      \;

      <\eqnarray*>
        <tformat|<table|<row|<cell|h=<frac|2m|n>>|<cell|for m>|<cell|To clear
        the fraction we use LCD = n>>|<row|<cell|>|<cell|>|<cell|>>|<row|<cell|<with|math-font-series|bold|(n)>h=<frac|<with|math-font-series|bold|(n)>2m|n>>|<cell|>|<cell|Multiply
        each term by n>>|<row|<cell|>|<cell|>|<cell|>>|<row|<cell|n
        h=2m>|<cell|>|<cell|Reduce n with denominators
        >>|<row|<cell|<with|math-font-series|bold|<wide| \ \ 2 \ \ |\<bar\>>
        \ \ \ \ \ \ \ \ \ <wide| \ \ 2 \ \ |\<bar\>>>>|<cell|>|<cell|Divide
        both sides by 2>>|<row|<cell|<frac|n h|2>=m>|<cell|>|<cell|Our
        Solution>>>>
      </eqnarray*>
    </example>

    The same pattern can be seen when we have several fractions in our
    problem.

    <\example>
      \;

      <\eqnarray*>
        <tformat|<table|<row|<cell|<frac|a|b><rsub|>+<frac|c|b>=e>|<cell|for
        a>|<cell|To clear the fraction we use LCD =
        b>>|<row|<cell|<frac|<with|math-font-series|bold|(b)>a|b>+<frac|<with|math-font-series|bold|(b)>c|b>=e
        <with|math-font-series|bold|(b)>>|<cell|>|<cell|Multiply each term by
        b>>|<row|<cell|a+c=e b>|<cell|>|<cell|Reduce b with
        denominators>>|<row|<cell|<wide*|<with|math-font-series|bold|-c
        \ \ \ -c>|\<bar\>>>|<cell|>|<cell|Subtract c from both
        sides>>|<row|<cell|a=e b-c>|<cell|>|<cell|Our Solution>>>>
      </eqnarray*>
    </example>

    Depending on the context of the problem we may find a formula that uses
    the same letter, one capital, one lowercase. These represent different
    values and we must be careful not to combine a capital variable with a
    lower case variable.\ 

    <\example>
      \;

      <\eqnarray*>
        <tformat|<table|<row|<cell|a=<frac|A|2-b>>|<cell|for b>|<cell|Use LCD
        (2-b) as a group>>|<row|<cell|>|<cell|>|<cell|>>|<row|<cell|<with|math-font-series|bold|(2-b)>a=<frac|<with|math-font-series|bold|(2-b)>A|2-b>>|<cell|>|<cell|Multiply
        each term by (2-b)>>|<row|<cell|>|<cell|>|<cell|>>|<row|<cell|(2-b)a=A>|<cell|>|<cell|reduce
        (2-b) with denominator>>|<row|<cell|2a-ab=A>|<cell|>|<cell|Distribute
        through parenthesis>>|<row|<cell|<with|math-font-series|bold|<wide*|-2a
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ -2a|\<bar\>>>>|<cell|>|<cell|Subtract 2a
        from both sides>>|<row|<cell|-ab=A-2a>|<cell|>|<cell|The b is
        multipied by -a>>|<row|<cell|<with|math-font-series|bold|<wide|-a|\<bar\>>
        \ \ \ \ \ <wide| \ \ \ \ -a \ \ \ \ \ \ |\<bar\>>>>|<cell|>|<cell|Divide
        both sides by -a>>|<row|<cell|b=<frac|A-2a|-a>>|<cell|>|<cell|Our
        Solution>>>>
      </eqnarray*>
    </example>

    Notice the <math|A> and <math|a> were not combined as like terms. This is
    because a formula will often use a capital letter and lower case letter
    to represent different variables. Often with formulas there is more than
    one way to solve for a variable. The next example solves the same problem
    in a slightly different manner. After clearing the denominator, we divide
    by <math|a> to move it to the other side, rather than distributing.

    <\example>
      \;

      <\eqnarray*>
        <tformat|<table|<row|<cell|a=<frac|A|2-b>>|<cell|for b>|<cell|Use LCD
        = (2-b) as a group>>|<row|<cell|>|<cell|>|<cell|>>|<row|<cell|<with|math-font-series|bold|(2-b)>a=<frac|<with|math-font-series|bold|(2-b)>A|2-b>>|<cell|>|<cell|Multiply
        each term by (2-b)>>|<row|<cell|(2-b)a=A>|<cell|>|<cell|Reduce (2-b)
        with denominator>>|<row|<cell|<with|math-font-series|bold|<wide|
        \ \ \ \ \ \ \ \ \ a \ \ \ \ \ \ \ \ \ |\<bar\>> \ \ \ \ <wide| \ \ a
        \ \ |\<bar\>>>>|<cell|>|<cell|Divide both sides by
        a>>|<row|<cell|2-b=<frac|A|a>>|<cell|>|<cell|Focus on the positive 2
        >>|<row|<cell|<with|math-font-series|bold|<wide*|-2
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ -2|\<bar\>>>>|<cell|>|<cell|Subtract
        2 from both sides>>|<row|<cell|-b=<frac|A|a>-2>|<cell|>|<cell|Still
        need to clear the negative>>|<row|<cell|<with|math-font-series|bold|(-1)>(-b)=<with|math-font-series|bold|(-1)><frac|A|a>-2<with|math-font-series|bold|(-1)>>|<cell|>|<cell|Multiply
        (or divide) each term by -1>>|<row|<cell|b=-<frac|A|a>+2>|<cell|>|<cell|Our
        Solution>>>>
      </eqnarray*>
    </example>

    Both answers to the last two examples are correct, they are just written
    in a different form because we solved them in different ways. This is
    very common with formulas, there may be more than one way to solve for a
    varaible, yet both are equivalent and correct.

    <strong|World View Note:> The father of algebra, Persian mathematician
    Muhammad ibn Musa Khwarizmi, introduced the fundamental idea of blancing
    by subtracting the same term to the other side of the equation. He called
    this process al-jabr which later became the world algebra.
  </with>
</body>