<TeXmacs|1.0.7.3>

<style|generic>

<\body>
  <doc-data|<doc-title|Solving Linear Equations - General Equations>>

  <\with|font-base-size|12>
    <strong|Objective: Solve general linear equations with variables on both
    sides.>

    Often as we are solving linear equations we will need to do some work to
    set them up into a form we are familiar with solving. This section will
    focus on manipulating an equation we are asked to solve in such a way
    that we can use our pattern for solving two-step equations to ultimately
    arrive at the solution.

    One such issue that needs to be addressed is parenthesis. Often the
    parenthesis can get in the way of solving an otherwise easy problem. As
    you might expect we can get rid of the unwanted parenthesis by using the
    distributive property. This is shown in the following example. Notice the
    first step is distributing, then it is solved like any other two-step
    equation.

    <\example>
      \;

      <\eqnarray*>
        <tformat|<table|<row|<cell|4(2x-6)=16>|<cell|>|<cell|Distribute 4
        through parenthesis>>|<row|<cell|8x-24=16>|<cell|>|<cell|Focus on the
        subtraction first>>|<row|<cell|<with|math-font-series|bold|<wide*|+24
        +24|\<bar\>>>>|<cell|>|<cell|Add 24 to both
        sides>>|<row|<cell|8x=40>|<cell|>|<cell|Now focus on the multiply by
        8>>|<row|<cell|<with|math-font-series|bold| <wide| \ \ 8
        \ \ |\<bar\>> \ \ \ \ <wide| \ \ 8
        \ \ |\<bar\>>>>|<cell|>|<cell|Divide both sides by
        8>>|<row|<cell|x=5>|<cell|>|<cell|Our Solution!>>>>
      </eqnarray*>
    </example>

    Often after we distribute there will be some like terms on one side of
    the equation. Example 2 shows distributing to clear the parenthesis and
    then combining like terms next. Notice we only combine like terms on the
    same side of the equation. Once we have done this, our next example
    solves just like any other two-step equation.

    <\example>
      \;

      <\eqnarray*>
        <tformat|<table|<row|<cell|3(2x-4)+9=15>|<cell|>|<cell|Distribute the
        3 through the parenthesis>>|<row|<cell|6x-12+9=15>|<cell|>|<cell|Combine
        like terms, -12+9>>|<row|<cell|6x-3=15>|<cell|>|<cell|Focus on the
        subtraction first>>|<row|<cell|<wide*|+3
        \ \ \ \ \ +3|\<bar\>>>|<cell|>|<cell|Add 3 to both
        sides>>|<row|<cell|6x=18>|<cell|>|<cell|Now focus on multiply by
        6>>|<row|<cell|<wide| \ \ 6 \ \ |\<bar\>> \ \ \ \ \ \ \ \ <wide|
        \ \ 6 \ \ |\<bar\>>>|<cell|>|<cell|Divide both sides by
        6>>|<row|<cell|x=3>|<cell|>|<cell|Our Solution>>>>
      </eqnarray*>
    </example>

    A second type of problem that becomes a two-step equation after a bit of
    work is one where we see the variable on both sides. This is shown in the
    following example.

    <\example>
      \;

      <\eqnarray*>
        <tformat|<table|<row|<cell|4x-6=2x+10>|<cell|>|<cell|>>>>
      </eqnarray*>

      Notice here the <em|x> is on both the left and right sides of the
      equation. This can make it difficult to decide which side to work with.
      We fix this by moving one of the terms with <math|x> to the other side,
      much like we moved a constant term. It doesn't matter which term gets
      moved, <math|4x> or <math|2x,> however, it would be the author's
      suggestion to move the smaller term (to avoid negative coefficients).
      For this reason we begin this problem by clearing the positive
      <math|2x> by subtracting <math|2x> from both sides.

      <\eqnarray*>
        <tformat|<table|<row|<cell|4x-6=2x+10>|<cell|>|<cell|Notice the
        variable on both sides>>|<row|<cell|<with|math-font-series|bold|<wide*|-2x
        \ \ \ \ \ \ \ \ \ \ \ \ \ -2x|\<bar\>>>
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ >|<cell|>|<cell|Subtract
        2x from both sides>>|<row|<cell|2x-6=10
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ >|<cell|>|<cell|Focus on the
        subtraction first>>|<row|<cell|<with|math-font-series|bold|<wide*|+6
        \ +6|\<bar\>>> \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ >|<cell|>|<cell|Add
        6 to both sides>>|<row|<cell|2x=16
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ >|<cell|>|<cell|Focus on the
        multiplication by 2>>|<row|<cell|
        \ \ <with|math-font-series|bold|<wide| \ \ 2 \ \ |\<bar\>> \ \ <wide|
        \ \ 2 \ \ |\<bar\>> \ \ \ \ \ \ \ \ \ \ \ \ >>|<cell|>|<cell|Divide
        both sides by 2>>|<row|<cell|x=8 \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ >|<cell|>|<cell|Our
        Solution!>>>>
      </eqnarray*>
    </example>

    The previous example shows the check on this solution. Here the solution
    is plugged into the <em|x> on both the left and right sides before
    simplifying.

    <\example>
      \;
    </example>

    <\eqnarray*>
      <tformat|<table|<row|<cell|4(8)-6=2(8)+10>|<cell|>|<cell|Multiply 4(8)
      and 2(8) first>>|<row|<cell|32-6=16+10 \ \ \ \ \ \ >|<cell|>|<cell|Add
      and Subtract>>|<row|<cell|26=26 \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ >|<cell|>|<cell|True!>>>>
    </eqnarray*>

    The next example illustrates the same process with negative coefficients.
    Notice first the smaller term with the variable is moved to the other
    side, this time by adding because the coefficient is negative.

    <\example>
      \;

      <\eqnarray*>
        <tformat|<table|<row|<cell|-3x+9=6x-27>|<cell|>|<cell|Notice the
        variable on both sides, -3x is smaller>>|<row|<cell|<with|math-font-series|bold|<wide*|+3x
        \ \ \ \ \ \ \ \ \ \ \ \ \ +3x|\<bar\>>>
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ >|<cell|>|<cell|Add 3x to
        both sides>>|<row|<cell|9=9x-27>|<cell|>|<cell|Focus on the
        subtraction by 27>>|<row|<cell|<with|math-font-series|bold|<wide*|+27
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ +27|\<bar\>>>>|<cell|>|<cell|Add 27
        to both sides>>|<row|<cell|36=9x \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ >|<cell|>|<cell|Focus
        on the mutiplication by 9>>|<row|<cell|
        \ <with|math-font-series|bold|<wide| \ \ 9 \ \ |\<bar\>>
        \ \ \ \ <wide| \ \ 9 \ \ |\<bar\>> \ >
        \ \ \ \ \ \ \ \ \ \ \ \ \ >|<cell|>|<cell|Divide both sides by
        9>>|<row|<cell|4=x \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ >|<cell|>|<cell|Our
        Solution>>>>
      </eqnarray*>
    </example>

    Linear equations can become particularly intersting when the two
    processes are combined. In the following problems we have parenthesis and
    the variable on both sides. Notice in each of the following examples we
    distribute, then combine like terms, then move the variable to one side
    of the equation. \ 

    <\example>
      \;

      <\eqnarray*>
        <tformat|<table|<row|<cell|2(x-5)+3x=x+18>|<cell|>|<cell|Distribute
        the 2 through parenthesis>>|<row|<cell|2x-10+3x=x+18>|<cell|>|<cell|Combine
        like terms 2x + 3x>>|<row|<cell|5x-10=x+18>|<cell|>|<cell|Notice the
        variable is on both sides>>|<row|<cell|<with|math-font-series|bold|<wide*|-x
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ -x|\<bar\>>>
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ >|<cell|>|<cell|Subtract x
        from both sides>>|<row|<cell|4x-10=18
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ >|<cell|>|<cell|Focus on the
        subtraction of 10>>|<row|<cell|<with|math-font-series|bold|<wide*|+10
        +10|\<bar\>>> \ \ \ \ \ \ \ \ \ \ \ \ \ \ >|<cell|>|<cell|Add 10 to
        both sides>>|<row|<cell|4x=28 \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ >|<cell|>|<cell|Focus
        on multiplication by 4>>|<row|<cell|<with|math-font-series|bold|
        <wide| \ \ 4 \ \ |\<bar\>> \ \ \ \ \ \ <wide| \ 4 \ \ |\<bar\>>>
        \ \ \ \ \ \ \ \ \ \ \ \ \ >|<cell|>|<cell|Divide both sides by
        4>>|<row|<cell|x=7 \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ >|<cell|>|<cell|Our
        Solution>>>>
      </eqnarray*>
    </example>

    Sometimes we may have to distribute more than once to clear several
    parenthesis. Remember to combine like terms after you distribute!

    <\example>
      \;

      <\eqnarray*>
        <tformat|<table|<row|<cell|3(4x-5)-4(2x+1)=5>|<cell|>|<cell|Distribute
        3 and -4 through parenthesis>>|<row|<cell|12x-15-8x-4=5>|<cell|>|<cell|Combine
        like terms 12x-8x and -15-4>>|<row|<cell|4x-19
        \ \ \ \ \ \ \ \ =5>|<cell|>|<cell|Focus on subtraction of
        19>>|<row|<cell|<wide*|<with|math-font-series|bold|+19
        +19>|\<bar\>>>|<cell|>|<cell|Add 19 to both
        sides>>|<row|<cell|4x=24>|<cell|>|<cell|Focus on multiplication by
        4>>|<row|<cell| <with|math-font-series|bold|<wide| \ \ 4
        \ \ |\<bar\>> \ \ \ \ <wide| \ \ 4
        \ \ |\<bar\>>>>|<cell|>|<cell|Divide both sides by
        4>>|<row|<cell|x=6>|<cell|>|<cell|Our Solution>>>>
      </eqnarray*>
    </example>

    This leads to a 5-step process to solve any linear equation. While all
    five steps aren't always needed, this can serve as a guide to solving
    equations.

    <\enumerate-numeric>
      <item>Distribute through any parentheses.

      <item>Combine like terms on each side of the equation.

      <item>Get the variables on one side by adding or subtracting

      <item>Solve the remaining 2-step equation (add or subtract then
      multiply or divide)

      <item>Check your answer by plugging it back in for <em|x> to find a
      true statement.
    </enumerate-numeric>

    The order of these steps is very important.\ 

    <strong|World View Note:> The Chinese developed a method for solving
    equations that involved finding each digit one at a time about 2000 years
    ago!

    We can see each of the above five steps worked through our next example.

    <\example>
      \;

      <\eqnarray*>
        <tformat|<table|<row|<cell|4(2x-6)+9=3(x-7)+8x>|<cell|>|<cell|Distribute
        4 and 3 through parenthesis>>|<row|<cell|8x-24+9=3x-21+8x>|<cell|>|<cell|Combine
        like terms -24+9 and 3x+8x>>|<row|<cell|8x-15=11x-21
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ >|<cell|>|<cell|Notice the variable
        is on both sides>>|<row|<cell|<with|math-font-series|bold|<wide*|-8x
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ -8x|\<bar\>>>
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ >|<cell|>|<cell|Subtract
        8x from both sides>>|<row|<cell|-15=3x-21
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ >|<cell|>|<cell|Focus
        on subtraction of 21>>|<row|<cell|<with|math-font-series|bold|<wide*|+21
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ +21|\<bar\>>>
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ >|<cell|>|<cell|Add 21
        to both sides>>|<row|<cell|6=3x \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ >|<cell|>|<cell|Focus
        on multiplication by 3>>|<row|<cell|
        <with|math-font-series|bold|<wide| \ \ 3 \ \ |\<bar\>> \ \ \ \ <wide|
        \ \ 3 \ \ |\<bar\>> \ \ \ > \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ >|<cell|>|<cell|Divide
        both sides by 3>>|<row|<cell|2=x \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ >|<cell|>|<cell|Our
        Solution>>>>
      </eqnarray*>

      <em|Check:>

      <\eqnarray*>
        <tformat|<table|<row|<cell|4[2(2)-6]+9=3[(2)-7]+8(2)>|<cell|>|<cell|Plug
        2 in for each x. Multiply inside parenthesis>>|<row|<cell|4[4-6]+9=3[-5]+8(2)
        \ \ \ \ \ \ \ \ \ \ \ \ \ >|<cell|>|<cell|Finish parentesis on left,
        multiply on right>>|<row|<cell|4[-2]+9=-15+8(2)
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ >|<cell|>|<cell|Finish
        multiplication on both sides>>|<row|<cell|-8+9=-15+16
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ >|<cell|>|<cell|Add>>|<row|<cell|1=1
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ >|<cell|>|<cell|True!>>>>
      </eqnarray*>
    </example>

    When we check our solution of <math|x=2> we found a true statement,
    <math|1=1>. Therefore, we know our solution <math|x=2> is the correct
    solution for the problem.\ 

    There are two special cases that can come up as we are solving these
    linear equations. The first is illustrated in the next two examples.
    Notice we start by distributing and moving the variables all to the same
    side.

    <\example>
      \;

      <\eqnarray*>
        <tformat|<table|<row|<cell|3(2x-5)=6x-15>|<cell|>|<cell|Distribute 3
        through parenthesis>>|<row|<cell|6x-15=6x-15>|<cell|>|<cell|Notice
        the variable on both sides>>|<row|<cell|<with|math-font-series|bold|<wide*|-6x
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ -6x |\<bar\>>>
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ >|<cell|>|<cell|Subtract 6x
        from both sides>>|<row|<cell|-15=-15
        \ \ \ \ \ \ \ \ \ \ \ \ \ >|<cell|>|<cell|Variable is gone! True!>>>>
      </eqnarray*>

      Here the variable subtracted out completely! We are left with a true
      statement, <math|-15=-15>. If the variables subtract out completely and
      we are left with a true statement, this indicates that the equation is
      always true, no matter what <math|x> is. Thus, for our solution we say
      <strong|all real numbers> or <with|mode|math|\<bbb-R\>>.
      <with|mode|math|>
    </example>

    <\example>
      \;

      <\eqnarray*>
        <tformat|<table|<row|<cell|2(3x-5)-4x=2x+7>|<cell|>|<cell|Distribute
        2 through parenthesis>>|<row|<cell|6x-10-4x=2x+7>|<cell|>|<cell|Combine
        like terms 6x-4x>>|<row|<cell|2x-10=2x+7>|<cell|>|<cell|Notice the
        variable is on both sides>>|<row|<cell|<with|math-font-series|bold|<wide*|-2x
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ -2x|\<bar\>> >
        \ \ \ \ \ \ \ \ \ \ \ \ \ \ >|<cell|>|<cell|Subtract 2x from both
        sides>>|<row|<cell|-10\<neq\>7 \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ >|<cell|>|<cell|Variable
        is gone! False!>>>>
      </eqnarray*>

      Again, the variable subtracted out completely! However, this time we
      are left with a false statement, this indicates that the equation is
      never true, no matter what <math|x> is. Thus, for our solution we say
      <strong|no solution> or <with|mode|math|\<varnothing\>>.
    </example>

    \;
  </with>
</body>